'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.findMatchVariable = exports.JsonToJsObj = exports.isMatchVars = exports.processMapVars = exports.replaceVariablestoDoc = exports.matchVar = exports.getVariblesFromDocument = exports.mapDocWithVariables = undefined;

var _typeof2 = require('babel-runtime/helpers/typeof');

var _typeof3 = _interopRequireDefault(_typeof2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var mapDocWithVariables = exports.mapDocWithVariables = function mapDocWithVariables(doc, variables) {
  var varsFromDocument = getVariblesFromDocument(doc);
  var variablesSet = matchVar(varsFromDocument, variables);
  var infoDoc = replaceVariablestoDoc(doc, variablesSet);
  return infoDoc;
};

var getVariblesFromDocument = exports.getVariblesFromDocument = function getVariblesFromDocument(doc) {
  var regExp = /\(([^)]+)\)/g;
  var matches = doc.match(regExp);
  var varsFromDocument = [];
  for (var i = 0; i < matches.length; i++) {
    var str = matches[i].substring(1, matches[i].length - 1);
    varsFromDocument.push(str);
  }
  return varsFromDocument;
};

var matchVar = exports.matchVar = function matchVar(varsFromDocument, variables) {
  var newVars = void 0;
  if (varsFromDocument.length !== variables.length) {
    throw 'Document and Variables does not match.';
  } else if (isMatchVars(varsFromDocument, variables)) {
    newVars = processMapVars(varsFromDocument, variables);
  }
  return newVars;
};

var replaceVariablestoDoc = exports.replaceVariablestoDoc = function replaceVariablestoDoc(doc, variablesSet) {
  var infoDoc = doc;
  var varsFromDocument = getVariblesFromDocument(doc);
  for (var i = 0; i < variablesSet.length; i++) {
    infoDoc = infoDoc.replace(varsFromDocument[i], variablesSet[i]);
  }
  return infoDoc;
};

var processMapVars = exports.processMapVars = function processMapVars(varsFromDocument, variables) {
  var newVars = varsFromDocument.map(function (varFromDoc, index) {
    var keys = Object.keys(variables[index]);
    var replaceValue = varFromDoc;
    for (var i = 0; i < keys.length; i++) {
      if ((0, _typeof3.default)(variables[index][keys[i]]) === 'object') {
        var varsToString = JsonToJsObj(variables[index][keys[i]]);
        replaceValue = replaceValue.replace('$' + keys[i], varsToString);
      } else {
        var _varsToString = JSON.stringify(variables[index][keys[i]]);
        replaceValue = replaceValue.replace('$' + keys[i], _varsToString);
      }
    }
    return replaceValue;
  });
  return newVars;
};

var isMatchVars = exports.isMatchVars = function isMatchVars(varsFromDocument, variables) {
  for (var i = 0; i < varsFromDocument.length; i++) {
    var splitVarsFromDocument = varsFromDocument[i].split(',');
    var vars = Object.keys(variables[i]);
    if (splitVarsFromDocument.length !== vars.length) {
      throw new Error('Variable length does not match.');
    }
    for (var n = 0; n < vars.length; n++) {
      var searchWord = findMatchVariable(splitVarsFromDocument[n].trim(), vars[n]);
      if (searchWord === -1) {
        throw new Error('\'' + vars[n] + '\' Variable and Document does not match.');
      }
    }
  }
  return true;
};

var JsonToJsObj = exports.JsonToJsObj = function JsonToJsObj(jsonData) {
  // const removeDoubleQuoteOfKey = /"[\w+]+"\:/g;
  var jsonStrData = JSON.stringify(jsonData);
  if (jsonData.length) {
    jsonData.forEach(function (data) {
      var objKeys = Object.keys(data);
      objKeys.forEach(function (key) {
        var regexStr = '"' + key + '":';
        jsonStrData = jsonStrData.replace(new RegExp(regexStr, 'g'), key + ':');
      });
    });
    return jsonStrData;
  }
  var objKeys = Object.keys(jsonData);
  objKeys.forEach(function (key) {
    var regexStr = '"' + key + '":';
    jsonStrData = jsonStrData.replace(new RegExp(regexStr, 'g'), key + ':');
  });
  return jsonStrData;
};

var findMatchVariable = exports.findMatchVariable = function findMatchVariable(splitVarsFromDocument, word) {
  var regx = new RegExp(word + '[]?$');
  return splitVarsFromDocument.search(regx);
};